# == Class: lldp
#
# Puppet module to install, deploy and configure lldp.
#
class lldp (
  $package           = true,
  $service           = true,
  $enable            = true,
  $force             = false,
  $lldp_package_name = $lldp::params::lldp_package_name,
  $lldp_service_name = $lldp::params::lldp_service_name
) inherits lldp::params {
  case $package {
    true    : { $ensure_package = 'present' }
    false   : { $ensure_package = 'purged' }
    latest  : { $ensure_package = 'latest' }
    default : { fail('package must be true, false or lastest') }
  }

  case $service {
    true    : { $ensure_service = 'running' }
    false   : { $ensure_service = 'stopped' }
    default : { fail('service must be true or false') }
  }

  if ($::is_virtual == false) or ($force == true) {
    package { $lldp_package_name:
      ensure => $ensure_package,
    }

    service { $lldp_service_name:
      ensure     => $ensure_service,
      enable     => $enable,
      hasrestart => true,
      hasstatus  => true,
      require    => Package[$lldp_package_name],
    }
  }
}
# EOF
